==> adventure-api-4.18.0-sources.jar: net/kyori/adventure/text/VirtualComponent.java <==
/*
 * This file is part of adventure, licensed under the MIT License.
 *
 * Copyright (c) 2017-2024 KyoriPowered
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package net.kyori.adventure.text;

import org.jetbrains.annotations.NotNull;

/**
 * A virtual component.
 *
 * <p>This component type is transient, and not guaranteed to survive during any sort of transformations or serialization.</p>
 *
 * @since 4.18.0
 */
public interface VirtualComponent extends TextComponent {
  /**
   * Gets the renderer context type.
   *
   * @return the renderer context type
   * @since 4.18.0
   */
  @NotNull Class<?> contextType();

  /**
   * Gets the renderer.
   *
   * @return the renderer
   * @since 4.18.0
   */
  @NotNull VirtualComponentRenderer<?> renderer();
}

==> adventure-api-4.26.1-sources.jar: net/kyori/adventure/text/VirtualComponent.java <==
/*
 * This file is part of adventure, licensed under the MIT License.
 *
 * Copyright (c) 2017-2025 KyoriPowered
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package net.kyori.adventure.text;

import org.jetbrains.annotations.ApiStatus;
import org.jetbrains.annotations.NotNull;

/**
 * A virtual component.
 *
 * <p>This component type is transient and not guaranteed to survive during any sort of transformations or serialization.</p>
 *
 * @see Component#virtual(Class, VirtualComponentRenderer)
 * @since 4.18.0
 */
@ApiStatus.NonExtendable
public interface VirtualComponent extends TextComponent {
  /**
   * Gets the renderer context type.
   *
   * @return the renderer context type
   * @since 4.18.0
   */
  @NotNull Class<?> contextType();

  /**
   * Gets the renderer.
   *
   * @return the renderer
   * @since 4.18.0
   */
  @NotNull VirtualComponentRenderer<?> renderer();
}
